@@ -4,12 +4,12 @@ This is a cutomized python package for plotting and data processing in stellarat
 how to use:
 
 """
-__version__ = '0.2.13'
+__version__ = '0.2.24'
 
 # local packages
 from .misc import colorbar, get_figure, kwargs2dict, map_matrix
 from .misc import print_progress, toroidal_period, vmecMN, xy2rp
-from .misc import trigfft, fft_deriv, trig2real
+from .misc import trigfft, fft_deriv, trig2real, vmec2focus
 from .hdf5 import HDF5
 from .surface import FourSurf
 from .dipole import Dipole
